"""Define project metadata
"""

__all__ = [
    '__title__',
    '__summary__',
    '__url__',
    '__version__',
    '__author__',
    '__email__',
    '__license__',
]

__title__ = 'ladder'
__summary__ = 'HTTP client wrapper with URL generation via object ' + \
              'notation and argument passing'
__url__ = 'https://github.com/dgilland/ladder'

__version__ = '0.2.3'

__author__ = 'Derrick Gilland'
__email__ = 'dgilland@gmail.com'

__license__ = 'MIT License'
